/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIShellService.idl
 */

#ifndef __gen_nsIShellService_h__
#define __gen_nsIShellService_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIShellService */
#define NS_ISHELLSERVICE_IID_STR "95f53544-f445-48d1-b3a2-d54aa020bc3d"

#define NS_ISHELLSERVICE_IID \
  {0x95f53544, 0xf445, 0x48d1, \
    { 0xb3, 0xa2, 0xd5, 0x4a, 0xa0, 0x20, 0xbc, 0x3d }}

class NS_NO_VTABLE nsIShellService : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_ISHELLSERVICE_IID)

  /**
   * app types we can be registered to handle
   */
  enum { MAIL = 1U };

  enum { NEWS = 2U };

  enum { RSS = 4U };

  /**
   * Determines whether or not Thunderbird is the "Default Client" for the 
   * passed in app type.
   *
   * This is simply whether or not Thunderbid is registered to handle 
   * the url scheme associatd with the app.
   * 
   * @param aStartupCheck true if this is the check being performed
   *                      by the first mail window at startup, 
   *                      false otherwise.
   * @param aApps the application types being tested (Mail, News, RSS, etc.)
   */
  /* boolean isDefaultClient (in boolean aStartupCheck, in unsigned short aApps); */
  NS_IMETHOD IsDefaultClient(PRBool aStartupCheck, PRUint16 aApps, PRBool *_retval) = 0;

  /**
   * Registers Thunderbird as the "Default Mail Client" for the
   * passed in app type.
   *
   * @param aForAllUsers   Whether or not Thunderbird should attempt
   *                       to become the default client for all
   *                       users on a multi-user system. 
   * @param aApps the application types being tested (Mail, News, RSS, etc.)
   */
  /* void setDefaultClient (in boolean aForAllUsers, in unsigned short aApps); */
  NS_IMETHOD SetDefaultClient(PRBool aForAllUsers, PRUint16 aApps) = 0;

  /** 
   * Used to determine whether or not to show a "Set Default Client"
   * query dialog. This attribute is true if the application is starting
   * up and "mail.shell.checkDefaultClient" is true, otherwise it
   * is false.
   */
  /* attribute boolean shouldCheckDefaultClient; */
  NS_IMETHOD GetShouldCheckDefaultClient(PRBool *aShouldCheckDefaultClient) = 0;
  NS_IMETHOD SetShouldCheckDefaultClient(PRBool aShouldCheckDefaultClient) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSISHELLSERVICE \
  NS_IMETHOD IsDefaultClient(PRBool aStartupCheck, PRUint16 aApps, PRBool *_retval); \
  NS_IMETHOD SetDefaultClient(PRBool aForAllUsers, PRUint16 aApps); \
  NS_IMETHOD GetShouldCheckDefaultClient(PRBool *aShouldCheckDefaultClient); \
  NS_IMETHOD SetShouldCheckDefaultClient(PRBool aShouldCheckDefaultClient); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSISHELLSERVICE(_to) \
  NS_IMETHOD IsDefaultClient(PRBool aStartupCheck, PRUint16 aApps, PRBool *_retval) { return _to IsDefaultClient(aStartupCheck, aApps, _retval); } \
  NS_IMETHOD SetDefaultClient(PRBool aForAllUsers, PRUint16 aApps) { return _to SetDefaultClient(aForAllUsers, aApps); } \
  NS_IMETHOD GetShouldCheckDefaultClient(PRBool *aShouldCheckDefaultClient) { return _to GetShouldCheckDefaultClient(aShouldCheckDefaultClient); } \
  NS_IMETHOD SetShouldCheckDefaultClient(PRBool aShouldCheckDefaultClient) { return _to SetShouldCheckDefaultClient(aShouldCheckDefaultClient); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSISHELLSERVICE(_to) \
  NS_IMETHOD IsDefaultClient(PRBool aStartupCheck, PRUint16 aApps, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->IsDefaultClient(aStartupCheck, aApps, _retval); } \
  NS_IMETHOD SetDefaultClient(PRBool aForAllUsers, PRUint16 aApps) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDefaultClient(aForAllUsers, aApps); } \
  NS_IMETHOD GetShouldCheckDefaultClient(PRBool *aShouldCheckDefaultClient) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetShouldCheckDefaultClient(aShouldCheckDefaultClient); } \
  NS_IMETHOD SetShouldCheckDefaultClient(PRBool aShouldCheckDefaultClient) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetShouldCheckDefaultClient(aShouldCheckDefaultClient); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsShellService : public nsIShellService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSISHELLSERVICE

  nsShellService();

private:
  ~nsShellService();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsShellService, nsIShellService)

nsShellService::nsShellService()
{
  /* member initializers and constructor code */
}

nsShellService::~nsShellService()
{
  /* destructor code */
}

/* boolean isDefaultClient (in boolean aStartupCheck, in unsigned short aApps); */
NS_IMETHODIMP nsShellService::IsDefaultClient(PRBool aStartupCheck, PRUint16 aApps, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void setDefaultClient (in boolean aForAllUsers, in unsigned short aApps); */
NS_IMETHODIMP nsShellService::SetDefaultClient(PRBool aForAllUsers, PRUint16 aApps)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean shouldCheckDefaultClient; */
NS_IMETHODIMP nsShellService::GetShouldCheckDefaultClient(PRBool *aShouldCheckDefaultClient)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsShellService::SetShouldCheckDefaultClient(PRBool aShouldCheckDefaultClient)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIShellService_h__ */
