/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * The Mozilla Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2007
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   David Bienvenu <bienvenu@mozilla.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
#include "nsISupports.idl"

interface nsIMsgFolder;
interface nsISupportsArray;

// This is similar to nsIFolderListener, but with slightly different semantics,
// especially w.r.t. moving messages and folders.  Some listeners want to know
// about moves, instead of getting an itemAdded and itemRemoved notification.
// Folder listeners also only tend to get called if a view is open on the folder,
// which is not always the case. I don't want to change nsIFolderListener at this
// point since there are lots of extensions that rely on it. Eventually,
// these two interfaces should be combined somehow.

[scriptable, uuid(1202F417-4580-4F02-89E5-151BA2C6E3C7)]
interface nsIMsgFolderListener : nsISupports {
  // new msg or folder added
  void itemAdded(in nsISupports aItem);
  // folder or msg deleted (no trash)
  void itemDeleted(in nsISupports aItem);
  void itemMoveCopyCompleted(in boolean aMove, 
                              in nsISupportsArray aSrcItems, 
                              in nsIMsgFolder aDestFolder);
                              
  void folderRenamed(in nsIMsgFolder aOrigFolder, in nsIMsgFolder aNewFolder);
  // extensibility hook
  void itemEvent(in nsISupports aItem, in ACString aEvent, in nsISupports aData);
};

