/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2001
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Paul Sandoz <paul.sandoz@sun.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
 
#include "nsISupports.idl"

#include "nsIAbCard.idl"
#include "nsIAbDirectory.idl"

[scriptable, uuid(08669294-66C6-414e-AE2D-69348A62F362)]
interface nsIAbMDBDirectory : nsISupports {

	// Creates an RDF directory component from the
	// uriName, adds it to its children and returns
	// the component
	nsIAbDirectory addDirectory(in string uriName);

	// This just returns the uri on the RDF resource
	string getDirUri();


	// Mail list specific
	//

	// Removes all elements from the addressLists
	// property
	[noscript] void removeElementsFromAddressList();

	// Specific to a directory which stores mail lists
	//

	// Adds a directory to the addressLists attribute
	void addMailListToDirectory(in nsIAbDirectory mailList);

	// Specific to a directory which is a mail list
	//

	// Copies mail list properties from the srcList
	void copyDBMailList(in nsIAbMDBDirectory srcListDB);

	// Adds a card to the addressList attribute
	void addAddressToList(in nsIAbCard card);

	// Removes items from the addressLists member
	void removeEmailAddressAt(in unsigned long aIndex);

    attribute unsigned long dbRowID;

	// Empty implementation, called by the data base
	[noscript] void notifyDirItemAdded(in nsISupports item);
	
	[noscript] void clearDatabase();
	
  // Check if the directory has a card for the specified email address
	boolean hasCardForEmailAddress(in string emailAddress);
  
  /** 
   * returns the address card for the specified email address. Returns NULL if 
   * we were unable to find a card for the specified e-mail address
   */
  nsIAbCard cardForEmailAddress(in string emailAddress);
};
