/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIDBChangeAnnouncer.idl
 */

#ifndef __gen_nsIDBChangeAnnouncer_h__
#define __gen_nsIDBChangeAnnouncer_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_MailNewsTypes2_h__
#include "MailNewsTypes2.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIDBChangeListener; /* forward declaration */

class nsIMsgDBHdr; /* forward declaration */


/* starting interface:    nsIDBChangeAnnouncer */
#define NS_IDBCHANGEANNOUNCER_IID_STR "22baf00b-939d-42c3-ac51-21d99dfa1f05"

#define NS_IDBCHANGEANNOUNCER_IID \
  {0x22baf00b, 0x939d, 0x42c3, \
    { 0xac, 0x51, 0x21, 0xd9, 0x9d, 0xfa, 0x1f, 0x05 }}

class NS_NO_VTABLE nsIDBChangeAnnouncer : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IDBCHANGEANNOUNCER_IID)

  /* void AddListener (in nsIDBChangeListener listener); */
  NS_IMETHOD AddListener(nsIDBChangeListener *listener) = 0;

  /* void RemoveListener (in nsIDBChangeListener listener); */
  NS_IMETHOD RemoveListener(nsIDBChangeListener *listener) = 0;

  /* void NotifyHdrChangeAll (in nsIMsgDBHdr aHdrChanged, in unsigned long aOldFlags, in unsigned long aNewFlags, in nsIDBChangeListener instigator); */
  NS_IMETHOD NotifyHdrChangeAll(nsIMsgDBHdr *aHdrChanged, PRUint32 aOldFlags, PRUint32 aNewFlags, nsIDBChangeListener *instigator) = 0;

  /* void NotifyHdrAddedAll (in nsIMsgDBHdr aHdrAdded, in nsMsgKey parentKey, in long flags, in nsIDBChangeListener instigator); */
  NS_IMETHOD NotifyHdrAddedAll(nsIMsgDBHdr *aHdrAdded, nsMsgKey parentKey, PRInt32 flags, nsIDBChangeListener *instigator) = 0;

  /* void NotifyHdrDeletedAll (in nsIMsgDBHdr aHdrDeleted, in nsMsgKey parentKey, in long flags, in nsIDBChangeListener instigator); */
  NS_IMETHOD NotifyHdrDeletedAll(nsIMsgDBHdr *aHdrDeleted, nsMsgKey parentKey, PRInt32 flags, nsIDBChangeListener *instigator) = 0;

  /* void NotifyParentChangedAll (in nsMsgKey keyReparented, in nsMsgKey oldParent, in nsMsgKey newParent, in nsIDBChangeListener instigator); */
  NS_IMETHOD NotifyParentChangedAll(nsMsgKey keyReparented, nsMsgKey oldParent, nsMsgKey newParent, nsIDBChangeListener *instigator) = 0;

  /* void NotifyReadChanged (in nsIDBChangeListener instigator); */
  NS_IMETHOD NotifyReadChanged(nsIDBChangeListener *instigator) = 0;

  /* void NotifyJunkScoreChanged (in nsIDBChangeListener aInstigator); */
  NS_IMETHOD NotifyJunkScoreChanged(nsIDBChangeListener *aInstigator) = 0;

  /* void NotifyAnnouncerGoingAway (); */
  NS_IMETHOD NotifyAnnouncerGoingAway(void) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIDBCHANGEANNOUNCER \
  NS_IMETHOD AddListener(nsIDBChangeListener *listener); \
  NS_IMETHOD RemoveListener(nsIDBChangeListener *listener); \
  NS_IMETHOD NotifyHdrChangeAll(nsIMsgDBHdr *aHdrChanged, PRUint32 aOldFlags, PRUint32 aNewFlags, nsIDBChangeListener *instigator); \
  NS_IMETHOD NotifyHdrAddedAll(nsIMsgDBHdr *aHdrAdded, nsMsgKey parentKey, PRInt32 flags, nsIDBChangeListener *instigator); \
  NS_IMETHOD NotifyHdrDeletedAll(nsIMsgDBHdr *aHdrDeleted, nsMsgKey parentKey, PRInt32 flags, nsIDBChangeListener *instigator); \
  NS_IMETHOD NotifyParentChangedAll(nsMsgKey keyReparented, nsMsgKey oldParent, nsMsgKey newParent, nsIDBChangeListener *instigator); \
  NS_IMETHOD NotifyReadChanged(nsIDBChangeListener *instigator); \
  NS_IMETHOD NotifyJunkScoreChanged(nsIDBChangeListener *aInstigator); \
  NS_IMETHOD NotifyAnnouncerGoingAway(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIDBCHANGEANNOUNCER(_to) \
  NS_IMETHOD AddListener(nsIDBChangeListener *listener) { return _to AddListener(listener); } \
  NS_IMETHOD RemoveListener(nsIDBChangeListener *listener) { return _to RemoveListener(listener); } \
  NS_IMETHOD NotifyHdrChangeAll(nsIMsgDBHdr *aHdrChanged, PRUint32 aOldFlags, PRUint32 aNewFlags, nsIDBChangeListener *instigator) { return _to NotifyHdrChangeAll(aHdrChanged, aOldFlags, aNewFlags, instigator); } \
  NS_IMETHOD NotifyHdrAddedAll(nsIMsgDBHdr *aHdrAdded, nsMsgKey parentKey, PRInt32 flags, nsIDBChangeListener *instigator) { return _to NotifyHdrAddedAll(aHdrAdded, parentKey, flags, instigator); } \
  NS_IMETHOD NotifyHdrDeletedAll(nsIMsgDBHdr *aHdrDeleted, nsMsgKey parentKey, PRInt32 flags, nsIDBChangeListener *instigator) { return _to NotifyHdrDeletedAll(aHdrDeleted, parentKey, flags, instigator); } \
  NS_IMETHOD NotifyParentChangedAll(nsMsgKey keyReparented, nsMsgKey oldParent, nsMsgKey newParent, nsIDBChangeListener *instigator) { return _to NotifyParentChangedAll(keyReparented, oldParent, newParent, instigator); } \
  NS_IMETHOD NotifyReadChanged(nsIDBChangeListener *instigator) { return _to NotifyReadChanged(instigator); } \
  NS_IMETHOD NotifyJunkScoreChanged(nsIDBChangeListener *aInstigator) { return _to NotifyJunkScoreChanged(aInstigator); } \
  NS_IMETHOD NotifyAnnouncerGoingAway(void) { return _to NotifyAnnouncerGoingAway(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIDBCHANGEANNOUNCER(_to) \
  NS_IMETHOD AddListener(nsIDBChangeListener *listener) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddListener(listener); } \
  NS_IMETHOD RemoveListener(nsIDBChangeListener *listener) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveListener(listener); } \
  NS_IMETHOD NotifyHdrChangeAll(nsIMsgDBHdr *aHdrChanged, PRUint32 aOldFlags, PRUint32 aNewFlags, nsIDBChangeListener *instigator) { return !_to ? NS_ERROR_NULL_POINTER : _to->NotifyHdrChangeAll(aHdrChanged, aOldFlags, aNewFlags, instigator); } \
  NS_IMETHOD NotifyHdrAddedAll(nsIMsgDBHdr *aHdrAdded, nsMsgKey parentKey, PRInt32 flags, nsIDBChangeListener *instigator) { return !_to ? NS_ERROR_NULL_POINTER : _to->NotifyHdrAddedAll(aHdrAdded, parentKey, flags, instigator); } \
  NS_IMETHOD NotifyHdrDeletedAll(nsIMsgDBHdr *aHdrDeleted, nsMsgKey parentKey, PRInt32 flags, nsIDBChangeListener *instigator) { return !_to ? NS_ERROR_NULL_POINTER : _to->NotifyHdrDeletedAll(aHdrDeleted, parentKey, flags, instigator); } \
  NS_IMETHOD NotifyParentChangedAll(nsMsgKey keyReparented, nsMsgKey oldParent, nsMsgKey newParent, nsIDBChangeListener *instigator) { return !_to ? NS_ERROR_NULL_POINTER : _to->NotifyParentChangedAll(keyReparented, oldParent, newParent, instigator); } \
  NS_IMETHOD NotifyReadChanged(nsIDBChangeListener *instigator) { return !_to ? NS_ERROR_NULL_POINTER : _to->NotifyReadChanged(instigator); } \
  NS_IMETHOD NotifyJunkScoreChanged(nsIDBChangeListener *aInstigator) { return !_to ? NS_ERROR_NULL_POINTER : _to->NotifyJunkScoreChanged(aInstigator); } \
  NS_IMETHOD NotifyAnnouncerGoingAway(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->NotifyAnnouncerGoingAway(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsDBChangeAnnouncer : public nsIDBChangeAnnouncer
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIDBCHANGEANNOUNCER

  nsDBChangeAnnouncer();

private:
  ~nsDBChangeAnnouncer();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsDBChangeAnnouncer, nsIDBChangeAnnouncer)

nsDBChangeAnnouncer::nsDBChangeAnnouncer()
{
  /* member initializers and constructor code */
}

nsDBChangeAnnouncer::~nsDBChangeAnnouncer()
{
  /* destructor code */
}

/* void AddListener (in nsIDBChangeListener listener); */
NS_IMETHODIMP nsDBChangeAnnouncer::AddListener(nsIDBChangeListener *listener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void RemoveListener (in nsIDBChangeListener listener); */
NS_IMETHODIMP nsDBChangeAnnouncer::RemoveListener(nsIDBChangeListener *listener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void NotifyHdrChangeAll (in nsIMsgDBHdr aHdrChanged, in unsigned long aOldFlags, in unsigned long aNewFlags, in nsIDBChangeListener instigator); */
NS_IMETHODIMP nsDBChangeAnnouncer::NotifyHdrChangeAll(nsIMsgDBHdr *aHdrChanged, PRUint32 aOldFlags, PRUint32 aNewFlags, nsIDBChangeListener *instigator)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void NotifyHdrAddedAll (in nsIMsgDBHdr aHdrAdded, in nsMsgKey parentKey, in long flags, in nsIDBChangeListener instigator); */
NS_IMETHODIMP nsDBChangeAnnouncer::NotifyHdrAddedAll(nsIMsgDBHdr *aHdrAdded, nsMsgKey parentKey, PRInt32 flags, nsIDBChangeListener *instigator)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void NotifyHdrDeletedAll (in nsIMsgDBHdr aHdrDeleted, in nsMsgKey parentKey, in long flags, in nsIDBChangeListener instigator); */
NS_IMETHODIMP nsDBChangeAnnouncer::NotifyHdrDeletedAll(nsIMsgDBHdr *aHdrDeleted, nsMsgKey parentKey, PRInt32 flags, nsIDBChangeListener *instigator)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void NotifyParentChangedAll (in nsMsgKey keyReparented, in nsMsgKey oldParent, in nsMsgKey newParent, in nsIDBChangeListener instigator); */
NS_IMETHODIMP nsDBChangeAnnouncer::NotifyParentChangedAll(nsMsgKey keyReparented, nsMsgKey oldParent, nsMsgKey newParent, nsIDBChangeListener *instigator)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void NotifyReadChanged (in nsIDBChangeListener instigator); */
NS_IMETHODIMP nsDBChangeAnnouncer::NotifyReadChanged(nsIDBChangeListener *instigator)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void NotifyJunkScoreChanged (in nsIDBChangeListener aInstigator); */
NS_IMETHODIMP nsDBChangeAnnouncer::NotifyJunkScoreChanged(nsIDBChangeListener *aInstigator)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void NotifyAnnouncerGoingAway (); */
NS_IMETHODIMP nsDBChangeAnnouncer::NotifyAnnouncerGoingAway()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIDBChangeAnnouncer_h__ */
