/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgHost.idl
 */

#ifndef __gen_nsIMsgHost_h__
#define __gen_nsIMsgHost_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMsgHost */
#define NS_IMSGHOST_IID_STR "adfb3740-aa57-11d2-b7ed-00805f05ffa5"

#define NS_IMSGHOST_IID \
  {0xadfb3740, 0xaa57, 0x11d2, \
    { 0xb7, 0xed, 0x00, 0x80, 0x5f, 0x05, 0xff, 0xa5 }}

class NS_NO_VTABLE nsIMsgHost : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGHOST_IID)

  /* attribute string hostname; */
  NS_IMETHOD GetHostname(char * *aHostname) = 0;
  NS_IMETHOD SetHostname(const char * aHostname) = 0;

  /* attribute string uiName; */
  NS_IMETHOD GetUiName(char * *aUiName) = 0;
  NS_IMETHOD SetUiName(const char * aUiName) = 0;

  /* attribute long port; */
  NS_IMETHOD GetPort(PRInt32 *aPort) = 0;
  NS_IMETHOD SetPort(PRInt32 aPort) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGHOST \
  NS_IMETHOD GetHostname(char * *aHostname); \
  NS_IMETHOD SetHostname(const char * aHostname); \
  NS_IMETHOD GetUiName(char * *aUiName); \
  NS_IMETHOD SetUiName(const char * aUiName); \
  NS_IMETHOD GetPort(PRInt32 *aPort); \
  NS_IMETHOD SetPort(PRInt32 aPort); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGHOST(_to) \
  NS_IMETHOD GetHostname(char * *aHostname) { return _to GetHostname(aHostname); } \
  NS_IMETHOD SetHostname(const char * aHostname) { return _to SetHostname(aHostname); } \
  NS_IMETHOD GetUiName(char * *aUiName) { return _to GetUiName(aUiName); } \
  NS_IMETHOD SetUiName(const char * aUiName) { return _to SetUiName(aUiName); } \
  NS_IMETHOD GetPort(PRInt32 *aPort) { return _to GetPort(aPort); } \
  NS_IMETHOD SetPort(PRInt32 aPort) { return _to SetPort(aPort); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGHOST(_to) \
  NS_IMETHOD GetHostname(char * *aHostname) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetHostname(aHostname); } \
  NS_IMETHOD SetHostname(const char * aHostname) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetHostname(aHostname); } \
  NS_IMETHOD GetUiName(char * *aUiName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetUiName(aUiName); } \
  NS_IMETHOD SetUiName(const char * aUiName) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetUiName(aUiName); } \
  NS_IMETHOD GetPort(PRInt32 *aPort) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetPort(aPort); } \
  NS_IMETHOD SetPort(PRInt32 aPort) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetPort(aPort); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgHost : public nsIMsgHost
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGHOST

  nsMsgHost();

private:
  ~nsMsgHost();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgHost, nsIMsgHost)

nsMsgHost::nsMsgHost()
{
  /* member initializers and constructor code */
}

nsMsgHost::~nsMsgHost()
{
  /* destructor code */
}

/* attribute string hostname; */
NS_IMETHODIMP nsMsgHost::GetHostname(char * *aHostname)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgHost::SetHostname(const char * aHostname)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string uiName; */
NS_IMETHODIMP nsMsgHost::GetUiName(char * *aUiName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgHost::SetUiName(const char * aUiName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute long port; */
NS_IMETHODIMP nsMsgHost::GetPort(PRInt32 *aPort)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgHost::SetPort(PRInt32 aPort)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgHost_h__ */
