/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIPop3URL.idl
 */

#ifndef __gen_nsIPop3URL_h__
#define __gen_nsIPop3URL_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIPop3Sink_h__
#include "nsIPop3Sink.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIPop3URL */
#define NS_IPOP3URL_IID_STR "73c043d0-b7e2-11d2-ab5c-00805f8ac968"

#define NS_IPOP3URL_IID \
  {0x73c043d0, 0xb7e2, 0x11d2, \
    { 0xab, 0x5c, 0x00, 0x80, 0x5f, 0x8a, 0xc9, 0x68 }}

class NS_NO_VTABLE nsIPop3URL : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IPOP3URL_IID)

  /* attribute nsIPop3Sink pop3Sink; */
  NS_IMETHOD GetPop3Sink(nsIPop3Sink * *aPop3Sink) = 0;
  NS_IMETHOD SetPop3Sink(nsIPop3Sink * aPop3Sink) = 0;

  /* attribute string messageUri; */
  NS_IMETHOD GetMessageUri(char * *aMessageUri) = 0;
  NS_IMETHOD SetMessageUri(const char * aMessageUri) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIPOP3URL \
  NS_IMETHOD GetPop3Sink(nsIPop3Sink * *aPop3Sink); \
  NS_IMETHOD SetPop3Sink(nsIPop3Sink * aPop3Sink); \
  NS_IMETHOD GetMessageUri(char * *aMessageUri); \
  NS_IMETHOD SetMessageUri(const char * aMessageUri); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIPOP3URL(_to) \
  NS_IMETHOD GetPop3Sink(nsIPop3Sink * *aPop3Sink) { return _to GetPop3Sink(aPop3Sink); } \
  NS_IMETHOD SetPop3Sink(nsIPop3Sink * aPop3Sink) { return _to SetPop3Sink(aPop3Sink); } \
  NS_IMETHOD GetMessageUri(char * *aMessageUri) { return _to GetMessageUri(aMessageUri); } \
  NS_IMETHOD SetMessageUri(const char * aMessageUri) { return _to SetMessageUri(aMessageUri); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIPOP3URL(_to) \
  NS_IMETHOD GetPop3Sink(nsIPop3Sink * *aPop3Sink) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetPop3Sink(aPop3Sink); } \
  NS_IMETHOD SetPop3Sink(nsIPop3Sink * aPop3Sink) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetPop3Sink(aPop3Sink); } \
  NS_IMETHOD GetMessageUri(char * *aMessageUri) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMessageUri(aMessageUri); } \
  NS_IMETHOD SetMessageUri(const char * aMessageUri) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMessageUri(aMessageUri); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsPop3URL : public nsIPop3URL
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIPOP3URL

  nsPop3URL();

private:
  ~nsPop3URL();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsPop3URL, nsIPop3URL)

nsPop3URL::nsPop3URL()
{
  /* member initializers and constructor code */
}

nsPop3URL::~nsPop3URL()
{
  /* destructor code */
}

/* attribute nsIPop3Sink pop3Sink; */
NS_IMETHODIMP nsPop3URL::GetPop3Sink(nsIPop3Sink * *aPop3Sink)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsPop3URL::SetPop3Sink(nsIPop3Sink * aPop3Sink)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string messageUri; */
NS_IMETHODIMP nsPop3URL::GetMessageUri(char * *aMessageUri)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsPop3URL::SetMessageUri(const char * aMessageUri)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIPop3URL_h__ */
