/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgComposeProgressParams.idl
 */

#ifndef __gen_nsIMsgComposeProgressParams_h__
#define __gen_nsIMsgComposeProgressParams_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIMsgCompose_h__
#include "nsIMsgCompose.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMsgComposeProgressParams */
#define NS_IMSGCOMPOSEPROGRESSPARAMS_IID_STR "1e0e7c00-3e4c-11d5-9daa-f88d288130fc"

#define NS_IMSGCOMPOSEPROGRESSPARAMS_IID \
  {0x1e0e7c00, 0x3e4c, 0x11d5, \
    { 0x9d, 0xaa, 0xf8, 0x8d, 0x28, 0x81, 0x30, 0xfc }}

class NS_NO_VTABLE nsIMsgComposeProgressParams : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGCOMPOSEPROGRESSPARAMS_IID)

  /* attribute wstring subject; */
  NS_IMETHOD GetSubject(PRUnichar * *aSubject) = 0;
  NS_IMETHOD SetSubject(const PRUnichar * aSubject) = 0;

  /* attribute MSG_DeliverMode deliveryMode; */
  NS_IMETHOD GetDeliveryMode(MSG_DeliverMode *aDeliveryMode) = 0;
  NS_IMETHOD SetDeliveryMode(MSG_DeliverMode aDeliveryMode) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGCOMPOSEPROGRESSPARAMS \
  NS_IMETHOD GetSubject(PRUnichar * *aSubject); \
  NS_IMETHOD SetSubject(const PRUnichar * aSubject); \
  NS_IMETHOD GetDeliveryMode(MSG_DeliverMode *aDeliveryMode); \
  NS_IMETHOD SetDeliveryMode(MSG_DeliverMode aDeliveryMode); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGCOMPOSEPROGRESSPARAMS(_to) \
  NS_IMETHOD GetSubject(PRUnichar * *aSubject) { return _to GetSubject(aSubject); } \
  NS_IMETHOD SetSubject(const PRUnichar * aSubject) { return _to SetSubject(aSubject); } \
  NS_IMETHOD GetDeliveryMode(MSG_DeliverMode *aDeliveryMode) { return _to GetDeliveryMode(aDeliveryMode); } \
  NS_IMETHOD SetDeliveryMode(MSG_DeliverMode aDeliveryMode) { return _to SetDeliveryMode(aDeliveryMode); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGCOMPOSEPROGRESSPARAMS(_to) \
  NS_IMETHOD GetSubject(PRUnichar * *aSubject) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSubject(aSubject); } \
  NS_IMETHOD SetSubject(const PRUnichar * aSubject) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSubject(aSubject); } \
  NS_IMETHOD GetDeliveryMode(MSG_DeliverMode *aDeliveryMode) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDeliveryMode(aDeliveryMode); } \
  NS_IMETHOD SetDeliveryMode(MSG_DeliverMode aDeliveryMode) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDeliveryMode(aDeliveryMode); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgComposeProgressParams : public nsIMsgComposeProgressParams
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGCOMPOSEPROGRESSPARAMS

  nsMsgComposeProgressParams();

private:
  ~nsMsgComposeProgressParams();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgComposeProgressParams, nsIMsgComposeProgressParams)

nsMsgComposeProgressParams::nsMsgComposeProgressParams()
{
  /* member initializers and constructor code */
}

nsMsgComposeProgressParams::~nsMsgComposeProgressParams()
{
  /* destructor code */
}

/* attribute wstring subject; */
NS_IMETHODIMP nsMsgComposeProgressParams::GetSubject(PRUnichar * *aSubject)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgComposeProgressParams::SetSubject(const PRUnichar * aSubject)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute MSG_DeliverMode deliveryMode; */
NS_IMETHODIMP nsMsgComposeProgressParams::GetDeliveryMode(MSG_DeliverMode *aDeliveryMode)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgComposeProgressParams::SetDeliveryMode(MSG_DeliverMode aDeliveryMode)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgComposeProgressParams_h__ */
