/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgSMIMECompFields.idl
 */

#ifndef __gen_nsIMsgSMIMECompFields_h__
#define __gen_nsIMsgSMIMECompFields_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMsgSMIMECompFields */
#define NS_IMSGSMIMECOMPFIELDS_IID_STR "338e91f9-5970-4f81-b771-0822a32b1161"

#define NS_IMSGSMIMECOMPFIELDS_IID \
  {0x338e91f9, 0x5970, 0x4f81, \
    { 0xb7, 0x71, 0x08, 0x22, 0xa3, 0x2b, 0x11, 0x61 }}

class NS_NO_VTABLE nsIMsgSMIMECompFields : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGSMIMECOMPFIELDS_IID)

  /* attribute boolean signMessage; */
  NS_IMETHOD GetSignMessage(PRBool *aSignMessage) = 0;
  NS_IMETHOD SetSignMessage(PRBool aSignMessage) = 0;

  /* attribute boolean requireEncryptMessage; */
  NS_IMETHOD GetRequireEncryptMessage(PRBool *aRequireEncryptMessage) = 0;
  NS_IMETHOD SetRequireEncryptMessage(PRBool aRequireEncryptMessage) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGSMIMECOMPFIELDS \
  NS_IMETHOD GetSignMessage(PRBool *aSignMessage); \
  NS_IMETHOD SetSignMessage(PRBool aSignMessage); \
  NS_IMETHOD GetRequireEncryptMessage(PRBool *aRequireEncryptMessage); \
  NS_IMETHOD SetRequireEncryptMessage(PRBool aRequireEncryptMessage); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGSMIMECOMPFIELDS(_to) \
  NS_IMETHOD GetSignMessage(PRBool *aSignMessage) { return _to GetSignMessage(aSignMessage); } \
  NS_IMETHOD SetSignMessage(PRBool aSignMessage) { return _to SetSignMessage(aSignMessage); } \
  NS_IMETHOD GetRequireEncryptMessage(PRBool *aRequireEncryptMessage) { return _to GetRequireEncryptMessage(aRequireEncryptMessage); } \
  NS_IMETHOD SetRequireEncryptMessage(PRBool aRequireEncryptMessage) { return _to SetRequireEncryptMessage(aRequireEncryptMessage); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGSMIMECOMPFIELDS(_to) \
  NS_IMETHOD GetSignMessage(PRBool *aSignMessage) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSignMessage(aSignMessage); } \
  NS_IMETHOD SetSignMessage(PRBool aSignMessage) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSignMessage(aSignMessage); } \
  NS_IMETHOD GetRequireEncryptMessage(PRBool *aRequireEncryptMessage) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetRequireEncryptMessage(aRequireEncryptMessage); } \
  NS_IMETHOD SetRequireEncryptMessage(PRBool aRequireEncryptMessage) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetRequireEncryptMessage(aRequireEncryptMessage); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgSMIMECompFields : public nsIMsgSMIMECompFields
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGSMIMECOMPFIELDS

  nsMsgSMIMECompFields();

private:
  ~nsMsgSMIMECompFields();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgSMIMECompFields, nsIMsgSMIMECompFields)

nsMsgSMIMECompFields::nsMsgSMIMECompFields()
{
  /* member initializers and constructor code */
}

nsMsgSMIMECompFields::~nsMsgSMIMECompFields()
{
  /* destructor code */
}

/* attribute boolean signMessage; */
NS_IMETHODIMP nsMsgSMIMECompFields::GetSignMessage(PRBool *aSignMessage)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSMIMECompFields::SetSignMessage(PRBool aSignMessage)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean requireEncryptMessage; */
NS_IMETHODIMP nsMsgSMIMECompFields::GetRequireEncryptMessage(PRBool *aRequireEncryptMessage)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgSMIMECompFields::SetRequireEncryptMessage(PRBool aRequireEncryptMessage)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgSMIMECompFields_h__ */
