/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIImportModule.idl
 */

#ifndef __gen_nsIImportModule_h__
#define __gen_nsIImportModule_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIImportModule */
#define NS_IIMPORTMODULE_IID_STR "624f0280-173f-11d3-a206-00a0cc26da63"

#define NS_IIMPORTMODULE_IID \
  {0x624f0280, 0x173f, 0x11d3, \
    { 0xa2, 0x06, 0x00, 0xa0, 0xcc, 0x26, 0xda, 0x63 }}

class NS_NO_VTABLE nsIImportModule : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IIMPORTMODULE_IID)

  /* readonly attribute wstring name; */
  NS_IMETHOD GetName(PRUnichar * *aName) = 0;

  /* readonly attribute wstring description; */
  NS_IMETHOD GetDescription(PRUnichar * *aDescription) = 0;

  /* readonly attribute string supports; */
  NS_IMETHOD GetSupports(char * *aSupports) = 0;

  /* readonly attribute boolean supportsUpgrade; */
  NS_IMETHOD GetSupportsUpgrade(PRBool *aSupportsUpgrade) = 0;

  /* nsISupports GetImportInterface (in string importType); */
  NS_IMETHOD GetImportInterface(const char *importType, nsISupports **_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIIMPORTMODULE \
  NS_IMETHOD GetName(PRUnichar * *aName); \
  NS_IMETHOD GetDescription(PRUnichar * *aDescription); \
  NS_IMETHOD GetSupports(char * *aSupports); \
  NS_IMETHOD GetSupportsUpgrade(PRBool *aSupportsUpgrade); \
  NS_IMETHOD GetImportInterface(const char *importType, nsISupports **_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIIMPORTMODULE(_to) \
  NS_IMETHOD GetName(PRUnichar * *aName) { return _to GetName(aName); } \
  NS_IMETHOD GetDescription(PRUnichar * *aDescription) { return _to GetDescription(aDescription); } \
  NS_IMETHOD GetSupports(char * *aSupports) { return _to GetSupports(aSupports); } \
  NS_IMETHOD GetSupportsUpgrade(PRBool *aSupportsUpgrade) { return _to GetSupportsUpgrade(aSupportsUpgrade); } \
  NS_IMETHOD GetImportInterface(const char *importType, nsISupports **_retval) { return _to GetImportInterface(importType, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIIMPORTMODULE(_to) \
  NS_IMETHOD GetName(PRUnichar * *aName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetName(aName); } \
  NS_IMETHOD GetDescription(PRUnichar * *aDescription) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDescription(aDescription); } \
  NS_IMETHOD GetSupports(char * *aSupports) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSupports(aSupports); } \
  NS_IMETHOD GetSupportsUpgrade(PRBool *aSupportsUpgrade) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSupportsUpgrade(aSupportsUpgrade); } \
  NS_IMETHOD GetImportInterface(const char *importType, nsISupports **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetImportInterface(importType, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsImportModule : public nsIImportModule
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIIMPORTMODULE

  nsImportModule();

private:
  ~nsImportModule();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsImportModule, nsIImportModule)

nsImportModule::nsImportModule()
{
  /* member initializers and constructor code */
}

nsImportModule::~nsImportModule()
{
  /* destructor code */
}

/* readonly attribute wstring name; */
NS_IMETHODIMP nsImportModule::GetName(PRUnichar * *aName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute wstring description; */
NS_IMETHODIMP nsImportModule::GetDescription(PRUnichar * *aDescription)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute string supports; */
NS_IMETHODIMP nsImportModule::GetSupports(char * *aSupports)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean supportsUpgrade; */
NS_IMETHODIMP nsImportModule::GetSupportsUpgrade(PRBool *aSupportsUpgrade)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsISupports GetImportInterface (in string importType); */
NS_IMETHODIMP nsImportModule::GetImportInterface(const char *importType, nsISupports **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif

#define NS_IMPORT_MAIL_STR		"mail"
#define NS_IMPORT_ADDRESS_STR	"addressbook"
#define	NS_IMPORT_SETTINGS_STR	"settings"

#endif /* __gen_nsIImportModule_h__ */
