/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications.
 * Portions created by the Initial Developer are Copyright (C) 2001
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Vidur Apparao <vidur@netscape.com> (original author)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"
#include "nsISchema.idl"

interface nsIWSDLBinding;
interface nsIWSDLPort;
interface nsIWSDLOperation;
interface nsIWSDLMessage;
interface nsIWSDLPart;
interface nsIDOMElement;

[scriptable, uuid(0458dac1-65de-11d5-9b42-00104bdf5339)]
interface nsIWSDLPort : nsISupports
{ 
  readonly attribute AString name;
  readonly attribute nsIDOMElement documentation;

  readonly attribute nsIWSDLBinding binding;

  readonly attribute PRUint32 operationCount;
  nsIWSDLOperation getOperation(in PRUint32 index);
  nsIWSDLOperation getOperationByName(in AString name);
};

[scriptable, uuid(0458dac2-65de-11d5-9b42-00104bdf5339)]
interface nsIWSDLOperation : nsISupports
{
  readonly attribute AString name;
  readonly attribute nsIDOMElement documentation;

  readonly attribute nsIWSDLBinding binding;

  readonly attribute nsIWSDLMessage input;
  readonly attribute nsIWSDLMessage output;
  readonly attribute PRUint32 faultCount;
  nsIWSDLMessage getFault(in PRUint32 index);

  readonly attribute PRUint32 parameterOrderCount;
  AString getParameter(in PRUint32 index);
  PRUint32 getParameterIndex(in AString name);
};

[scriptable, uuid(0458dac3-65de-11d5-9b42-00104bdf5339)]
interface nsIWSDLMessage : nsISupports
{
  readonly attribute AString name;
  readonly attribute nsIDOMElement documentation;

  readonly attribute nsIWSDLBinding binding;
  
  readonly attribute PRUint32 partCount;
  nsIWSDLPart getPart(in PRUint32 index);
  nsIWSDLPart getPartByName(in AString name);
};

[scriptable, uuid(0458dac4-65de-11d5-9b42-00104bdf5339)]
interface nsIWSDLPart : nsISupports
{
  readonly attribute AString name;

  readonly attribute nsIWSDLBinding binding;
  
  readonly attribute AString type;
  readonly attribute AString elementName;

  /**
   * The schema component that corresponds to this part. If the
   * type attribute is used, this is a nsISchemaType. If the 
   * elementName attribute is used, it is a nsISchemaElement.
   */
  readonly attribute nsISchemaComponent schemaComponent;
};

[scriptable, uuid(0458dac0-65de-11d5-9b42-00104bdf5339)]
interface nsIWSDLBinding : nsISupports
{
  readonly attribute AString protocol;
  readonly attribute nsIDOMElement documentation;
};

