/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgFolderNotificationService.idl
 */

#ifndef __gen_nsIMsgFolderNotificationService_h__
#define __gen_nsIMsgFolderNotificationService_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgFolder; /* forward declaration */

class nsIMsgFolderListener; /* forward declaration */

class nsISupportsArray; /* forward declaration */


/* starting interface:    nsIMsgFolderNotificationService */
#define NS_IMSGFOLDERNOTIFICATIONSERVICE_IID_STR "4264c2dc-96ac-48b7-9822-dd4396ebb674"

#define NS_IMSGFOLDERNOTIFICATIONSERVICE_IID \
  {0x4264c2dc, 0x96ac, 0x48b7, \
    { 0x98, 0x22, 0xdd, 0x43, 0x96, 0xeb, 0xb6, 0x74 }}

class NS_NO_VTABLE nsIMsgFolderNotificationService : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGFOLDERNOTIFICATIONSERVICE_IID)

  /* readonly attribute boolean hasListeners; */
  NS_IMETHOD GetHasListeners(PRBool *aHasListeners) = 0;

  /* void addListener (in nsIMsgFolderListener aListener); */
  NS_IMETHOD AddListener(nsIMsgFolderListener *aListener) = 0;

  /* void removeListener (in nsIMsgFolderListener aListener); */
  NS_IMETHOD RemoveListener(nsIMsgFolderListener *aListener) = 0;

  /* void notifyItemAdded (in nsISupports aItem); */
  NS_IMETHOD NotifyItemAdded(nsISupports *aItem) = 0;

  /* void notifyItemDeleted (in nsISupports aItem); */
  NS_IMETHOD NotifyItemDeleted(nsISupports *aItem) = 0;

  /* void notifyItemMoveCopyCompleted (in boolean aMove, in nsISupportsArray aSrcItems, in nsIMsgFolder aDestFolder); */
  NS_IMETHOD NotifyItemMoveCopyCompleted(PRBool aMove, nsISupportsArray *aSrcItems, nsIMsgFolder *aDestFolder) = 0;

  /* void notifyFolderRenamed (in nsIMsgFolder aOrigFolder, in nsIMsgFolder aNewFolder); */
  NS_IMETHOD NotifyFolderRenamed(nsIMsgFolder *aOrigFolder, nsIMsgFolder *aNewFolder) = 0;

  /* void notifyItemEvent (in nsISupports aItem, in ACString aEvent, in nsISupports aData); */
  NS_IMETHOD NotifyItemEvent(nsISupports *aItem, const nsACString & aEvent, nsISupports *aData) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGFOLDERNOTIFICATIONSERVICE \
  NS_IMETHOD GetHasListeners(PRBool *aHasListeners); \
  NS_IMETHOD AddListener(nsIMsgFolderListener *aListener); \
  NS_IMETHOD RemoveListener(nsIMsgFolderListener *aListener); \
  NS_IMETHOD NotifyItemAdded(nsISupports *aItem); \
  NS_IMETHOD NotifyItemDeleted(nsISupports *aItem); \
  NS_IMETHOD NotifyItemMoveCopyCompleted(PRBool aMove, nsISupportsArray *aSrcItems, nsIMsgFolder *aDestFolder); \
  NS_IMETHOD NotifyFolderRenamed(nsIMsgFolder *aOrigFolder, nsIMsgFolder *aNewFolder); \
  NS_IMETHOD NotifyItemEvent(nsISupports *aItem, const nsACString & aEvent, nsISupports *aData); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGFOLDERNOTIFICATIONSERVICE(_to) \
  NS_IMETHOD GetHasListeners(PRBool *aHasListeners) { return _to GetHasListeners(aHasListeners); } \
  NS_IMETHOD AddListener(nsIMsgFolderListener *aListener) { return _to AddListener(aListener); } \
  NS_IMETHOD RemoveListener(nsIMsgFolderListener *aListener) { return _to RemoveListener(aListener); } \
  NS_IMETHOD NotifyItemAdded(nsISupports *aItem) { return _to NotifyItemAdded(aItem); } \
  NS_IMETHOD NotifyItemDeleted(nsISupports *aItem) { return _to NotifyItemDeleted(aItem); } \
  NS_IMETHOD NotifyItemMoveCopyCompleted(PRBool aMove, nsISupportsArray *aSrcItems, nsIMsgFolder *aDestFolder) { return _to NotifyItemMoveCopyCompleted(aMove, aSrcItems, aDestFolder); } \
  NS_IMETHOD NotifyFolderRenamed(nsIMsgFolder *aOrigFolder, nsIMsgFolder *aNewFolder) { return _to NotifyFolderRenamed(aOrigFolder, aNewFolder); } \
  NS_IMETHOD NotifyItemEvent(nsISupports *aItem, const nsACString & aEvent, nsISupports *aData) { return _to NotifyItemEvent(aItem, aEvent, aData); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGFOLDERNOTIFICATIONSERVICE(_to) \
  NS_IMETHOD GetHasListeners(PRBool *aHasListeners) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetHasListeners(aHasListeners); } \
  NS_IMETHOD AddListener(nsIMsgFolderListener *aListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddListener(aListener); } \
  NS_IMETHOD RemoveListener(nsIMsgFolderListener *aListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveListener(aListener); } \
  NS_IMETHOD NotifyItemAdded(nsISupports *aItem) { return !_to ? NS_ERROR_NULL_POINTER : _to->NotifyItemAdded(aItem); } \
  NS_IMETHOD NotifyItemDeleted(nsISupports *aItem) { return !_to ? NS_ERROR_NULL_POINTER : _to->NotifyItemDeleted(aItem); } \
  NS_IMETHOD NotifyItemMoveCopyCompleted(PRBool aMove, nsISupportsArray *aSrcItems, nsIMsgFolder *aDestFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->NotifyItemMoveCopyCompleted(aMove, aSrcItems, aDestFolder); } \
  NS_IMETHOD NotifyFolderRenamed(nsIMsgFolder *aOrigFolder, nsIMsgFolder *aNewFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->NotifyFolderRenamed(aOrigFolder, aNewFolder); } \
  NS_IMETHOD NotifyItemEvent(nsISupports *aItem, const nsACString & aEvent, nsISupports *aData) { return !_to ? NS_ERROR_NULL_POINTER : _to->NotifyItemEvent(aItem, aEvent, aData); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgFolderNotificationService : public nsIMsgFolderNotificationService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGFOLDERNOTIFICATIONSERVICE

  nsMsgFolderNotificationService();

private:
  ~nsMsgFolderNotificationService();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgFolderNotificationService, nsIMsgFolderNotificationService)

nsMsgFolderNotificationService::nsMsgFolderNotificationService()
{
  /* member initializers and constructor code */
}

nsMsgFolderNotificationService::~nsMsgFolderNotificationService()
{
  /* destructor code */
}

/* readonly attribute boolean hasListeners; */
NS_IMETHODIMP nsMsgFolderNotificationService::GetHasListeners(PRBool *aHasListeners)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addListener (in nsIMsgFolderListener aListener); */
NS_IMETHODIMP nsMsgFolderNotificationService::AddListener(nsIMsgFolderListener *aListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void removeListener (in nsIMsgFolderListener aListener); */
NS_IMETHODIMP nsMsgFolderNotificationService::RemoveListener(nsIMsgFolderListener *aListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void notifyItemAdded (in nsISupports aItem); */
NS_IMETHODIMP nsMsgFolderNotificationService::NotifyItemAdded(nsISupports *aItem)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void notifyItemDeleted (in nsISupports aItem); */
NS_IMETHODIMP nsMsgFolderNotificationService::NotifyItemDeleted(nsISupports *aItem)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void notifyItemMoveCopyCompleted (in boolean aMove, in nsISupportsArray aSrcItems, in nsIMsgFolder aDestFolder); */
NS_IMETHODIMP nsMsgFolderNotificationService::NotifyItemMoveCopyCompleted(PRBool aMove, nsISupportsArray *aSrcItems, nsIMsgFolder *aDestFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void notifyFolderRenamed (in nsIMsgFolder aOrigFolder, in nsIMsgFolder aNewFolder); */
NS_IMETHODIMP nsMsgFolderNotificationService::NotifyFolderRenamed(nsIMsgFolder *aOrigFolder, nsIMsgFolder *aNewFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void notifyItemEvent (in nsISupports aItem, in ACString aEvent, in nsISupports aData); */
NS_IMETHODIMP nsMsgFolderNotificationService::NotifyItemEvent(nsISupports *aItem, const nsACString & aEvent, nsISupports *aData)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgFolderNotificationService_h__ */
