/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2001
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Brian Stell <bstell@netscape.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"

interface nsISimpleEnumerator;

/**
 * The nsIFontList interface provides an application the  
 * necessary information so that the user can select the font to use 
 * as the default style sheet. This is used if the style sheet is 
 * missing or does not specify a font.
 * <P>Font lists are specified per language group.
 *
 */

[scriptable, uuid(702909c6-1dd2-11b2-b833-8a740f643539)]
interface nsIFontList : nsISupports
{
    
  /**
   * Get the list of available fonts for a language group
   * and for use as the given CSS generic font.
   *
   * @param aLangGroup limits the fonts to fonts in a language 
   *          group; eg: x-western (American/Western European), 
   *          ar (Arabic), el (Greek), he (Hebrew), ja (Japanese),
   *          ko (Korean), th (Thai), tr (Turkish),
   *          x-baltic (Baltic), x-central-euro (Eastern European),
   *          x-cyrillic (Russian), zh-CN (China), zh-TW (Taiwan)
   *
   * @param aFontType limits the fonts to the fonts with this CSS 
   *          generic font type; eg: serif, sans-serif, cursive,
   *          fantasy, monospace.
   *
   * @return a simple enumerator of the available fonts for a 
   *          language group / generic type.  These strings are
   *          the text supplied by the operating system's font 
   *          system.
   */
  nsISimpleEnumerator availableFonts(in wstring aLangGroup, 
                                     in wstring aFontType);
};

