/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsICookieManager.idl"

interface nsICookie2;

/** 
 * Additions to the frozen nsICookieManager
 */

[scriptable, uuid(3E73FF5F-154E-494f-B640-3C654BA2CC2B)]
interface nsICookieManager2 : nsICookieManager
{
  /**
   * Add a cookie. nsICookieService is the normal way to do this. This
   * method is something of a backdoor.
   *
   * @param aDomain
   *        the host or domain for which the cookie is set. presence of a
   *        leading dot indicates a domain cookie; otherwise, the cookie
   *        is treated as a non-domain cookie. see RFC2109.
   * @param aPath
   *        path within the domain for which the cookie is valid
   * @param aName
   *        cookie name
   * @param aValue
   *        cookie data
   * @param aSecure
   *        true if the cookie should only be sent over a secure connection.
   * @param aIsSession
   *        true if the cookie should exist for the current session only.
   * @param aExpiry
   *        expiration date, in seconds since the epoch. only relevant if
   *        aIsSession is false.
   */
  void add(in AUTF8String aDomain,
           in AUTF8String aPath,
           in ACString    aName,
           in ACString    aValue,
           in boolean     aSecure,
           in boolean     aIsSession,
           in PRInt64     aExpiry);

  /**
   * Find whether a matching cookie already exists, and how many cookies
   * a given host has already set. This is useful when e.g. prompting the
   * user whether to accept a given cookie.
   *
   * @param aCookie
   *        the cookie to look for
   * @param aCountFromHost
   *        the number of cookies found whose hosts are the same as, or
   *        subdomains of, the host field of aCookie
   *
   * @return true if a cookie was found which matches the host, path, and name
   *         fields of aCookie
   */
  boolean findMatchingCookie(in nsICookie2     aCookie,
                             out unsigned long aCountFromHost);
};
