/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIURLFetcher.idl
 */

#ifndef __gen_nsIURLFetcher_h__
#define __gen_nsIURLFetcher_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIURI_h__
#include "nsIURI.h"
#endif

#ifndef __gen_nsIFileStreams_h__
#include "nsIFileStreams.h"
#endif

#ifndef __gen_nsILocalFile_h__
#include "nsILocalFile.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
//
// Callback declarations for URL completion
//
// For completion of send/message creation operations...
typedef nsresult (*nsAttachSaveCompletionCallback) (nsresult aStatus,
                                                    const char *aContentType,
                                                    const char *aCharset,
                                                    PRInt32 totalSize, const PRUnichar* aMsg, 
                                                    void *tagData);

/* starting interface:    nsIURLFetcher */
#define NS_IURLFETCHER_IID_STR "01b8a700-2f52-11d5-9daa-f78da781a1fc"

#define NS_IURLFETCHER_IID \
  {0x01b8a700, 0x2f52, 0x11d5, \
    { 0x9d, 0xaa, 0xf7, 0x8d, 0xa7, 0x81, 0xa1, 0xfc }}

class NS_NO_VTABLE nsIURLFetcher : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IURLFETCHER_IID)

  /* boolean stillRunning (); */
  NS_IMETHOD StillRunning(PRBool *_retval) = 0;

  /* void fireURLRequest (in nsIURI aURL, in nsILocalFile localFile, in nsIFileOutputStream fileStream, in nsAttachSaveCompletionCallback cb, in voidPtr tagData); */
  NS_IMETHOD FireURLRequest(nsIURI *aURL, nsILocalFile *localFile, nsIFileOutputStream *fileStream, nsAttachSaveCompletionCallback cb, void * tagData) = 0;

  /* void initialize (in nsILocalFile localFile, in nsIFileOutputStream fileStream, in nsAttachSaveCompletionCallback cb, in voidPtr tagData); */
  NS_IMETHOD Initialize(nsILocalFile *localFile, nsIFileOutputStream *fileStream, nsAttachSaveCompletionCallback cb, void * tagData) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIURLFETCHER \
  NS_IMETHOD StillRunning(PRBool *_retval); \
  NS_IMETHOD FireURLRequest(nsIURI *aURL, nsILocalFile *localFile, nsIFileOutputStream *fileStream, nsAttachSaveCompletionCallback cb, void * tagData); \
  NS_IMETHOD Initialize(nsILocalFile *localFile, nsIFileOutputStream *fileStream, nsAttachSaveCompletionCallback cb, void * tagData); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIURLFETCHER(_to) \
  NS_IMETHOD StillRunning(PRBool *_retval) { return _to StillRunning(_retval); } \
  NS_IMETHOD FireURLRequest(nsIURI *aURL, nsILocalFile *localFile, nsIFileOutputStream *fileStream, nsAttachSaveCompletionCallback cb, void * tagData) { return _to FireURLRequest(aURL, localFile, fileStream, cb, tagData); } \
  NS_IMETHOD Initialize(nsILocalFile *localFile, nsIFileOutputStream *fileStream, nsAttachSaveCompletionCallback cb, void * tagData) { return _to Initialize(localFile, fileStream, cb, tagData); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIURLFETCHER(_to) \
  NS_IMETHOD StillRunning(PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->StillRunning(_retval); } \
  NS_IMETHOD FireURLRequest(nsIURI *aURL, nsILocalFile *localFile, nsIFileOutputStream *fileStream, nsAttachSaveCompletionCallback cb, void * tagData) { return !_to ? NS_ERROR_NULL_POINTER : _to->FireURLRequest(aURL, localFile, fileStream, cb, tagData); } \
  NS_IMETHOD Initialize(nsILocalFile *localFile, nsIFileOutputStream *fileStream, nsAttachSaveCompletionCallback cb, void * tagData) { return !_to ? NS_ERROR_NULL_POINTER : _to->Initialize(localFile, fileStream, cb, tagData); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsURLFetcher : public nsIURLFetcher
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIURLFETCHER

  nsURLFetcher();

private:
  ~nsURLFetcher();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsURLFetcher, nsIURLFetcher)

nsURLFetcher::nsURLFetcher()
{
  /* member initializers and constructor code */
}

nsURLFetcher::~nsURLFetcher()
{
  /* destructor code */
}

/* boolean stillRunning (); */
NS_IMETHODIMP nsURLFetcher::StillRunning(PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void fireURLRequest (in nsIURI aURL, in nsILocalFile localFile, in nsIFileOutputStream fileStream, in nsAttachSaveCompletionCallback cb, in voidPtr tagData); */
NS_IMETHODIMP nsURLFetcher::FireURLRequest(nsIURI *aURL, nsILocalFile *localFile, nsIFileOutputStream *fileStream, nsAttachSaveCompletionCallback cb, void * tagData)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void initialize (in nsILocalFile localFile, in nsIFileOutputStream fileStream, in nsAttachSaveCompletionCallback cb, in voidPtr tagData); */
NS_IMETHODIMP nsURLFetcher::Initialize(nsILocalFile *localFile, nsIFileOutputStream *fileStream, nsAttachSaveCompletionCallback cb, void * tagData)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIURLFetcher_h__ */
