/* -*- Mode: IDL; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

/* This object represents the stream of data which will be sent to an
   NNTP server. You basically set up all the RFC850 required headers, etc,
   then pass it to something that reads off the nsIInputStream interface.
*/

#include "nsISupports.idl"

interface nsIFileSpec;

[scriptable, uuid(c4164a20-bc74-11d2-b7f2-00805f05ffa5)]
interface nsINNTPNewsgroupPost : nsISupports {
    
    /* from RFC850 */
    /* section 2.1 - required headers */
    attribute string relayVersion;
    attribute string postingVersion;
    attribute string from;
    attribute string date;
    
    void AddNewsgroup(in string newsgroupName);
    readonly attribute string newsgroups;
    
    attribute string subject;
    attribute string path;
    
    /* Secion 2.2 - optional headers */
    attribute string replyTo;
    attribute string sender;
    attribute string followupTo;
    attribute string dateRecieved;
    attribute string expires;

    readonly attribute string references;

    attribute string control;
    attribute string distribution;
    attribute string organization;

    /* the message itself */
    attribute string body;

    /* the path to the message */
    /* attribute nsFilePath postMessageFile; */
        
    /* is this a control message? */
    readonly attribute boolean isControl;

    attribute nsIFileSpec postMessageFile;
};



