/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgRecipientArray.idl
 */

#ifndef __gen_nsIMsgRecipientArray_h__
#define __gen_nsIMsgRecipientArray_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMsgRecipientArray */
#define NS_IMSGRECIPIENTARRAY_IID_STR "650c3281-a1bf-11d3-a449-d481b6e12daa"

#define NS_IMSGRECIPIENTARRAY_IID \
  {0x650c3281, 0xa1bf, 0x11d3, \
    { 0xa4, 0x49, 0xd4, 0x81, 0xb6, 0xe1, 0x2d, 0xaa }}

class NS_NO_VTABLE nsIMsgRecipientArray : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGRECIPIENTARRAY_IID)

  /* wstring StringAt (in long index); */
  NS_IMETHOD StringAt(PRInt32 index, PRUnichar **_retval) = 0;

  /* boolean AppendString (in wstring aString); */
  NS_IMETHOD AppendString(const PRUnichar *aString, PRBool *_retval) = 0;

  /* boolean RemoveStringAt (in long index); */
  NS_IMETHOD RemoveStringAt(PRInt32 index, PRBool *_retval) = 0;

  /* void Clear (); */
  NS_IMETHOD Clear(void) = 0;

  /* readonly attribute long count; */
  NS_IMETHOD GetCount(PRInt32 *aCount) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGRECIPIENTARRAY \
  NS_IMETHOD StringAt(PRInt32 index, PRUnichar **_retval); \
  NS_IMETHOD AppendString(const PRUnichar *aString, PRBool *_retval); \
  NS_IMETHOD RemoveStringAt(PRInt32 index, PRBool *_retval); \
  NS_IMETHOD Clear(void); \
  NS_IMETHOD GetCount(PRInt32 *aCount); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGRECIPIENTARRAY(_to) \
  NS_IMETHOD StringAt(PRInt32 index, PRUnichar **_retval) { return _to StringAt(index, _retval); } \
  NS_IMETHOD AppendString(const PRUnichar *aString, PRBool *_retval) { return _to AppendString(aString, _retval); } \
  NS_IMETHOD RemoveStringAt(PRInt32 index, PRBool *_retval) { return _to RemoveStringAt(index, _retval); } \
  NS_IMETHOD Clear(void) { return _to Clear(); } \
  NS_IMETHOD GetCount(PRInt32 *aCount) { return _to GetCount(aCount); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGRECIPIENTARRAY(_to) \
  NS_IMETHOD StringAt(PRInt32 index, PRUnichar **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->StringAt(index, _retval); } \
  NS_IMETHOD AppendString(const PRUnichar *aString, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->AppendString(aString, _retval); } \
  NS_IMETHOD RemoveStringAt(PRInt32 index, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveStringAt(index, _retval); } \
  NS_IMETHOD Clear(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Clear(); } \
  NS_IMETHOD GetCount(PRInt32 *aCount) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCount(aCount); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgRecipientArray : public nsIMsgRecipientArray
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGRECIPIENTARRAY

  nsMsgRecipientArray();

private:
  ~nsMsgRecipientArray();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgRecipientArray, nsIMsgRecipientArray)

nsMsgRecipientArray::nsMsgRecipientArray()
{
  /* member initializers and constructor code */
}

nsMsgRecipientArray::~nsMsgRecipientArray()
{
  /* destructor code */
}

/* wstring StringAt (in long index); */
NS_IMETHODIMP nsMsgRecipientArray::StringAt(PRInt32 index, PRUnichar **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean AppendString (in wstring aString); */
NS_IMETHODIMP nsMsgRecipientArray::AppendString(const PRUnichar *aString, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean RemoveStringAt (in long index); */
NS_IMETHODIMP nsMsgRecipientArray::RemoveStringAt(PRInt32 index, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void Clear (); */
NS_IMETHODIMP nsMsgRecipientArray::Clear()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute long count; */
NS_IMETHODIMP nsMsgRecipientArray::GetCount(PRInt32 *aCount)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgRecipientArray_h__ */
