/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgFolderListener.idl
 */

#ifndef __gen_nsIMsgFolderListener_h__
#define __gen_nsIMsgFolderListener_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgFolder; /* forward declaration */

class nsISupportsArray; /* forward declaration */


/* starting interface:    nsIMsgFolderListener */
#define NS_IMSGFOLDERLISTENER_IID_STR "1202f417-4580-4f02-89e5-151ba2c6e3c7"

#define NS_IMSGFOLDERLISTENER_IID \
  {0x1202f417, 0x4580, 0x4f02, \
    { 0x89, 0xe5, 0x15, 0x1b, 0xa2, 0xc6, 0xe3, 0xc7 }}

class NS_NO_VTABLE nsIMsgFolderListener : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGFOLDERLISTENER_IID)

  /* void itemAdded (in nsISupports aItem); */
  NS_IMETHOD ItemAdded(nsISupports *aItem) = 0;

  /* void itemDeleted (in nsISupports aItem); */
  NS_IMETHOD ItemDeleted(nsISupports *aItem) = 0;

  /* void itemMoveCopyCompleted (in boolean aMove, in nsISupportsArray aSrcItems, in nsIMsgFolder aDestFolder); */
  NS_IMETHOD ItemMoveCopyCompleted(PRBool aMove, nsISupportsArray *aSrcItems, nsIMsgFolder *aDestFolder) = 0;

  /* void folderRenamed (in nsIMsgFolder aOrigFolder, in nsIMsgFolder aNewFolder); */
  NS_IMETHOD FolderRenamed(nsIMsgFolder *aOrigFolder, nsIMsgFolder *aNewFolder) = 0;

  /* void itemEvent (in nsISupports aItem, in ACString aEvent, in nsISupports aData); */
  NS_IMETHOD ItemEvent(nsISupports *aItem, const nsACString & aEvent, nsISupports *aData) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGFOLDERLISTENER \
  NS_IMETHOD ItemAdded(nsISupports *aItem); \
  NS_IMETHOD ItemDeleted(nsISupports *aItem); \
  NS_IMETHOD ItemMoveCopyCompleted(PRBool aMove, nsISupportsArray *aSrcItems, nsIMsgFolder *aDestFolder); \
  NS_IMETHOD FolderRenamed(nsIMsgFolder *aOrigFolder, nsIMsgFolder *aNewFolder); \
  NS_IMETHOD ItemEvent(nsISupports *aItem, const nsACString & aEvent, nsISupports *aData); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGFOLDERLISTENER(_to) \
  NS_IMETHOD ItemAdded(nsISupports *aItem) { return _to ItemAdded(aItem); } \
  NS_IMETHOD ItemDeleted(nsISupports *aItem) { return _to ItemDeleted(aItem); } \
  NS_IMETHOD ItemMoveCopyCompleted(PRBool aMove, nsISupportsArray *aSrcItems, nsIMsgFolder *aDestFolder) { return _to ItemMoveCopyCompleted(aMove, aSrcItems, aDestFolder); } \
  NS_IMETHOD FolderRenamed(nsIMsgFolder *aOrigFolder, nsIMsgFolder *aNewFolder) { return _to FolderRenamed(aOrigFolder, aNewFolder); } \
  NS_IMETHOD ItemEvent(nsISupports *aItem, const nsACString & aEvent, nsISupports *aData) { return _to ItemEvent(aItem, aEvent, aData); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGFOLDERLISTENER(_to) \
  NS_IMETHOD ItemAdded(nsISupports *aItem) { return !_to ? NS_ERROR_NULL_POINTER : _to->ItemAdded(aItem); } \
  NS_IMETHOD ItemDeleted(nsISupports *aItem) { return !_to ? NS_ERROR_NULL_POINTER : _to->ItemDeleted(aItem); } \
  NS_IMETHOD ItemMoveCopyCompleted(PRBool aMove, nsISupportsArray *aSrcItems, nsIMsgFolder *aDestFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->ItemMoveCopyCompleted(aMove, aSrcItems, aDestFolder); } \
  NS_IMETHOD FolderRenamed(nsIMsgFolder *aOrigFolder, nsIMsgFolder *aNewFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->FolderRenamed(aOrigFolder, aNewFolder); } \
  NS_IMETHOD ItemEvent(nsISupports *aItem, const nsACString & aEvent, nsISupports *aData) { return !_to ? NS_ERROR_NULL_POINTER : _to->ItemEvent(aItem, aEvent, aData); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgFolderListener : public nsIMsgFolderListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGFOLDERLISTENER

  nsMsgFolderListener();

private:
  ~nsMsgFolderListener();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgFolderListener, nsIMsgFolderListener)

nsMsgFolderListener::nsMsgFolderListener()
{
  /* member initializers and constructor code */
}

nsMsgFolderListener::~nsMsgFolderListener()
{
  /* destructor code */
}

/* void itemAdded (in nsISupports aItem); */
NS_IMETHODIMP nsMsgFolderListener::ItemAdded(nsISupports *aItem)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void itemDeleted (in nsISupports aItem); */
NS_IMETHODIMP nsMsgFolderListener::ItemDeleted(nsISupports *aItem)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void itemMoveCopyCompleted (in boolean aMove, in nsISupportsArray aSrcItems, in nsIMsgFolder aDestFolder); */
NS_IMETHODIMP nsMsgFolderListener::ItemMoveCopyCompleted(PRBool aMove, nsISupportsArray *aSrcItems, nsIMsgFolder *aDestFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void folderRenamed (in nsIMsgFolder aOrigFolder, in nsIMsgFolder aNewFolder); */
NS_IMETHODIMP nsMsgFolderListener::FolderRenamed(nsIMsgFolder *aOrigFolder, nsIMsgFolder *aNewFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void itemEvent (in nsISupports aItem, in ACString aEvent, in nsISupports aData); */
NS_IMETHODIMP nsMsgFolderListener::ItemEvent(nsISupports *aItem, const nsACString & aEvent, nsISupports *aData)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgFolderListener_h__ */
