/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIMsgAccount.idl
 */

#ifndef __gen_nsIMsgAccount_h__
#define __gen_nsIMsgAccount_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIMsgIncomingServer_h__
#include "nsIMsgIncomingServer.h"
#endif

#ifndef __gen_nsIMsgIdentity_h__
#include "nsIMsgIdentity.h"
#endif

#ifndef __gen_nsISupportsArray_h__
#include "nsISupportsArray.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIMsgAccount */
#define NS_IMSGACCOUNT_IID_STR "da368bd0-e624-11d2-b7fc-00805f05ffa5"

#define NS_IMSGACCOUNT_IID \
  {0xda368bd0, 0xe624, 0x11d2, \
    { 0xb7, 0xfc, 0x00, 0x80, 0x5f, 0x05, 0xff, 0xa5 }}

class NS_NO_VTABLE nsIMsgAccount : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IMSGACCOUNT_IID)

  /* void init (); */
  NS_IMETHOD Init(void) = 0;

  /* attribute string key; */
  NS_IMETHOD GetKey(char * *aKey) = 0;
  NS_IMETHOD SetKey(const char * aKey) = 0;

  /* attribute nsIMsgIncomingServer incomingServer; */
  NS_IMETHOD GetIncomingServer(nsIMsgIncomingServer * *aIncomingServer) = 0;
  NS_IMETHOD SetIncomingServer(nsIMsgIncomingServer * aIncomingServer) = 0;

  /* readonly attribute nsISupportsArray identities; */
  NS_IMETHOD GetIdentities(nsISupportsArray * *aIdentities) = 0;

  /* attribute nsIMsgIdentity defaultIdentity; */
  NS_IMETHOD GetDefaultIdentity(nsIMsgIdentity * *aDefaultIdentity) = 0;
  NS_IMETHOD SetDefaultIdentity(nsIMsgIdentity * aDefaultIdentity) = 0;

  /* void addIdentity (in nsIMsgIdentity identity); */
  NS_IMETHOD AddIdentity(nsIMsgIdentity *identity) = 0;

  /* void removeIdentity (in nsIMsgIdentity identity); */
  NS_IMETHOD RemoveIdentity(nsIMsgIdentity *identity) = 0;

  /* void clearAllValues (); */
  NS_IMETHOD ClearAllValues(void) = 0;

  /* wstring toString (); */
  NS_IMETHOD ToString(PRUnichar **_retval) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIMSGACCOUNT \
  NS_IMETHOD Init(void); \
  NS_IMETHOD GetKey(char * *aKey); \
  NS_IMETHOD SetKey(const char * aKey); \
  NS_IMETHOD GetIncomingServer(nsIMsgIncomingServer * *aIncomingServer); \
  NS_IMETHOD SetIncomingServer(nsIMsgIncomingServer * aIncomingServer); \
  NS_IMETHOD GetIdentities(nsISupportsArray * *aIdentities); \
  NS_IMETHOD GetDefaultIdentity(nsIMsgIdentity * *aDefaultIdentity); \
  NS_IMETHOD SetDefaultIdentity(nsIMsgIdentity * aDefaultIdentity); \
  NS_IMETHOD AddIdentity(nsIMsgIdentity *identity); \
  NS_IMETHOD RemoveIdentity(nsIMsgIdentity *identity); \
  NS_IMETHOD ClearAllValues(void); \
  NS_IMETHOD ToString(PRUnichar **_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIMSGACCOUNT(_to) \
  NS_IMETHOD Init(void) { return _to Init(); } \
  NS_IMETHOD GetKey(char * *aKey) { return _to GetKey(aKey); } \
  NS_IMETHOD SetKey(const char * aKey) { return _to SetKey(aKey); } \
  NS_IMETHOD GetIncomingServer(nsIMsgIncomingServer * *aIncomingServer) { return _to GetIncomingServer(aIncomingServer); } \
  NS_IMETHOD SetIncomingServer(nsIMsgIncomingServer * aIncomingServer) { return _to SetIncomingServer(aIncomingServer); } \
  NS_IMETHOD GetIdentities(nsISupportsArray * *aIdentities) { return _to GetIdentities(aIdentities); } \
  NS_IMETHOD GetDefaultIdentity(nsIMsgIdentity * *aDefaultIdentity) { return _to GetDefaultIdentity(aDefaultIdentity); } \
  NS_IMETHOD SetDefaultIdentity(nsIMsgIdentity * aDefaultIdentity) { return _to SetDefaultIdentity(aDefaultIdentity); } \
  NS_IMETHOD AddIdentity(nsIMsgIdentity *identity) { return _to AddIdentity(identity); } \
  NS_IMETHOD RemoveIdentity(nsIMsgIdentity *identity) { return _to RemoveIdentity(identity); } \
  NS_IMETHOD ClearAllValues(void) { return _to ClearAllValues(); } \
  NS_IMETHOD ToString(PRUnichar **_retval) { return _to ToString(_retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIMSGACCOUNT(_to) \
  NS_IMETHOD Init(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Init(); } \
  NS_IMETHOD GetKey(char * *aKey) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetKey(aKey); } \
  NS_IMETHOD SetKey(const char * aKey) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetKey(aKey); } \
  NS_IMETHOD GetIncomingServer(nsIMsgIncomingServer * *aIncomingServer) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIncomingServer(aIncomingServer); } \
  NS_IMETHOD SetIncomingServer(nsIMsgIncomingServer * aIncomingServer) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetIncomingServer(aIncomingServer); } \
  NS_IMETHOD GetIdentities(nsISupportsArray * *aIdentities) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIdentities(aIdentities); } \
  NS_IMETHOD GetDefaultIdentity(nsIMsgIdentity * *aDefaultIdentity) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDefaultIdentity(aDefaultIdentity); } \
  NS_IMETHOD SetDefaultIdentity(nsIMsgIdentity * aDefaultIdentity) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDefaultIdentity(aDefaultIdentity); } \
  NS_IMETHOD AddIdentity(nsIMsgIdentity *identity) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddIdentity(identity); } \
  NS_IMETHOD RemoveIdentity(nsIMsgIdentity *identity) { return !_to ? NS_ERROR_NULL_POINTER : _to->RemoveIdentity(identity); } \
  NS_IMETHOD ClearAllValues(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->ClearAllValues(); } \
  NS_IMETHOD ToString(PRUnichar **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->ToString(_retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsMsgAccount : public nsIMsgAccount
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIMSGACCOUNT

  nsMsgAccount();

private:
  ~nsMsgAccount();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsMsgAccount, nsIMsgAccount)

nsMsgAccount::nsMsgAccount()
{
  /* member initializers and constructor code */
}

nsMsgAccount::~nsMsgAccount()
{
  /* destructor code */
}

/* void init (); */
NS_IMETHODIMP nsMsgAccount::Init()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string key; */
NS_IMETHODIMP nsMsgAccount::GetKey(char * *aKey)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgAccount::SetKey(const char * aKey)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIMsgIncomingServer incomingServer; */
NS_IMETHODIMP nsMsgAccount::GetIncomingServer(nsIMsgIncomingServer * *aIncomingServer)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgAccount::SetIncomingServer(nsIMsgIncomingServer * aIncomingServer)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsISupportsArray identities; */
NS_IMETHODIMP nsMsgAccount::GetIdentities(nsISupportsArray * *aIdentities)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIMsgIdentity defaultIdentity; */
NS_IMETHODIMP nsMsgAccount::GetDefaultIdentity(nsIMsgIdentity * *aDefaultIdentity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsMsgAccount::SetDefaultIdentity(nsIMsgIdentity * aDefaultIdentity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addIdentity (in nsIMsgIdentity identity); */
NS_IMETHODIMP nsMsgAccount::AddIdentity(nsIMsgIdentity *identity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void removeIdentity (in nsIMsgIdentity identity); */
NS_IMETHODIMP nsMsgAccount::RemoveIdentity(nsIMsgIdentity *identity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void clearAllValues (); */
NS_IMETHODIMP nsMsgAccount::ClearAllValues()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* wstring toString (); */
NS_IMETHODIMP nsMsgAccount::ToString(PRUnichar **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIMsgAccount_h__ */
