/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIXPInstallManagerUI.idl
 */

#ifndef __gen_nsIXPInstallManagerUI_h__
#define __gen_nsIXPInstallManagerUI_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIXPIProgressDialog; /* forward declaration */

class nsIDownload; /* forward declaration */


/* starting interface:    nsIXPInstallManagerUI */
#define NS_IXPINSTALLMANAGERUI_IID_STR "087f52a4-8fd8-40ab-ae52-c3e161810141"

#define NS_IXPINSTALLMANAGERUI_IID \
  {0x087f52a4, 0x8fd8, 0x40ab, \
    { 0xae, 0x52, 0xc3, 0xe1, 0x61, 0x81, 0x01, 0x41 }}

class NS_NO_VTABLE nsIXPInstallManagerUI : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IXPINSTALLMANAGERUI_IID)

  enum { INSTALL_DOWNLOADING = 5 };

  enum { INSTALL_INSTALLING = 6 };

  enum { INSTALL_FINISHED = 7 };

  enum { DOWNLOAD_TYPE_INSTALL = 1 };

  /* readonly attribute nsIXPIProgressDialog xpiProgress; */
  NS_IMETHOD GetXpiProgress(nsIXPIProgressDialog * *aXpiProgress) = 0;

  /* readonly attribute boolean hasActiveXPIOperations; */
  NS_IMETHOD GetHasActiveXPIOperations(PRBool *aHasActiveXPIOperations) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIXPINSTALLMANAGERUI \
  NS_IMETHOD GetXpiProgress(nsIXPIProgressDialog * *aXpiProgress); \
  NS_IMETHOD GetHasActiveXPIOperations(PRBool *aHasActiveXPIOperations); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIXPINSTALLMANAGERUI(_to) \
  NS_IMETHOD GetXpiProgress(nsIXPIProgressDialog * *aXpiProgress) { return _to GetXpiProgress(aXpiProgress); } \
  NS_IMETHOD GetHasActiveXPIOperations(PRBool *aHasActiveXPIOperations) { return _to GetHasActiveXPIOperations(aHasActiveXPIOperations); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIXPINSTALLMANAGERUI(_to) \
  NS_IMETHOD GetXpiProgress(nsIXPIProgressDialog * *aXpiProgress) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetXpiProgress(aXpiProgress); } \
  NS_IMETHOD GetHasActiveXPIOperations(PRBool *aHasActiveXPIOperations) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetHasActiveXPIOperations(aHasActiveXPIOperations); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsXPInstallManagerUI : public nsIXPInstallManagerUI
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIXPINSTALLMANAGERUI

  nsXPInstallManagerUI();

private:
  ~nsXPInstallManagerUI();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsXPInstallManagerUI, nsIXPInstallManagerUI)

nsXPInstallManagerUI::nsXPInstallManagerUI()
{
  /* member initializers and constructor code */
}

nsXPInstallManagerUI::~nsXPInstallManagerUI()
{
  /* destructor code */
}

/* readonly attribute nsIXPIProgressDialog xpiProgress; */
NS_IMETHODIMP nsXPInstallManagerUI::GetXpiProgress(nsIXPIProgressDialog * *aXpiProgress)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean hasActiveXPIOperations; */
NS_IMETHODIMP nsXPInstallManagerUI::GetHasActiveXPIOperations(PRBool *aHasActiveXPIOperations)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIXPInstallManagerUI_h__ */
