/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Shell Service.
 *
 * The Initial Developer of the Original Code is
 *   Scott MacGregor <mscott@mozilla.org>.
 * Portions created by the Initial Developer are Copyright (C) 2006
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */


#include "nsISupports.idl"

[scriptable, uuid(95F53544-F445-48d1-B3A2-D54AA020BC3D)]
interface nsIShellService : nsISupports
{
  /**
   * app types we can be registered to handle
   */
  const unsigned short MAIL = 0x0001;
  const unsigned short NEWS = 0x0002;
  const unsigned short RSS  = 0x0004;

  /**
   * Determines whether or not Thunderbird is the "Default Client" for the 
   * passed in app type.
   *
   * This is simply whether or not Thunderbid is registered to handle 
   * the url scheme associatd with the app.
   * 
   * @param aStartupCheck true if this is the check being performed
   *                      by the first mail window at startup, 
   *                      false otherwise.
   * @param aApps the application types being tested (Mail, News, RSS, etc.)
   */
  boolean isDefaultClient(in boolean aStartupCheck, in unsigned short aApps);

  /**
   * Registers Thunderbird as the "Default Mail Client" for the
   * passed in app type.
   *
   * @param aForAllUsers   Whether or not Thunderbird should attempt
   *                       to become the default client for all
   *                       users on a multi-user system. 
   * @param aApps the application types being tested (Mail, News, RSS, etc.)
   */
  void setDefaultClient(in boolean aForAllUsers, in unsigned short aApps);

  /** 
   * Used to determine whether or not to show a "Set Default Client"
   * query dialog. This attribute is true if the application is starting
   * up and "mail.shell.checkDefaultClient" is true, otherwise it
   * is false.
   */
  attribute boolean shouldCheckDefaultClient;
};
