/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsINNTPNewsgroupPost.idl
 */

#ifndef __gen_nsINNTPNewsgroupPost_h__
#define __gen_nsINNTPNewsgroupPost_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIFileSpec; /* forward declaration */


/* starting interface:    nsINNTPNewsgroupPost */
#define NS_INNTPNEWSGROUPPOST_IID_STR "c4164a20-bc74-11d2-b7f2-00805f05ffa5"

#define NS_INNTPNEWSGROUPPOST_IID \
  {0xc4164a20, 0xbc74, 0x11d2, \
    { 0xb7, 0xf2, 0x00, 0x80, 0x5f, 0x05, 0xff, 0xa5 }}

class NS_NO_VTABLE nsINNTPNewsgroupPost : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_INNTPNEWSGROUPPOST_IID)

  /* attribute string relayVersion; */
  NS_IMETHOD GetRelayVersion(char * *aRelayVersion) = 0;
  NS_IMETHOD SetRelayVersion(const char * aRelayVersion) = 0;

  /* attribute string postingVersion; */
  NS_IMETHOD GetPostingVersion(char * *aPostingVersion) = 0;
  NS_IMETHOD SetPostingVersion(const char * aPostingVersion) = 0;

  /* attribute string from; */
  NS_IMETHOD GetFrom(char * *aFrom) = 0;
  NS_IMETHOD SetFrom(const char * aFrom) = 0;

  /* attribute string date; */
  NS_IMETHOD GetDate(char * *aDate) = 0;
  NS_IMETHOD SetDate(const char * aDate) = 0;

  /* void AddNewsgroup (in string newsgroupName); */
  NS_IMETHOD AddNewsgroup(const char *newsgroupName) = 0;

  /* readonly attribute string newsgroups; */
  NS_IMETHOD GetNewsgroups(char * *aNewsgroups) = 0;

  /* attribute string subject; */
  NS_IMETHOD GetSubject(char * *aSubject) = 0;
  NS_IMETHOD SetSubject(const char * aSubject) = 0;

  /* attribute string path; */
  NS_IMETHOD GetPath(char * *aPath) = 0;
  NS_IMETHOD SetPath(const char * aPath) = 0;

  /* attribute string replyTo; */
  NS_IMETHOD GetReplyTo(char * *aReplyTo) = 0;
  NS_IMETHOD SetReplyTo(const char * aReplyTo) = 0;

  /* attribute string sender; */
  NS_IMETHOD GetSender(char * *aSender) = 0;
  NS_IMETHOD SetSender(const char * aSender) = 0;

  /* attribute string followupTo; */
  NS_IMETHOD GetFollowupTo(char * *aFollowupTo) = 0;
  NS_IMETHOD SetFollowupTo(const char * aFollowupTo) = 0;

  /* attribute string dateRecieved; */
  NS_IMETHOD GetDateRecieved(char * *aDateRecieved) = 0;
  NS_IMETHOD SetDateRecieved(const char * aDateRecieved) = 0;

  /* attribute string expires; */
  NS_IMETHOD GetExpires(char * *aExpires) = 0;
  NS_IMETHOD SetExpires(const char * aExpires) = 0;

  /* readonly attribute string references; */
  NS_IMETHOD GetReferences(char * *aReferences) = 0;

  /* attribute string control; */
  NS_IMETHOD GetControl(char * *aControl) = 0;
  NS_IMETHOD SetControl(const char * aControl) = 0;

  /* attribute string distribution; */
  NS_IMETHOD GetDistribution(char * *aDistribution) = 0;
  NS_IMETHOD SetDistribution(const char * aDistribution) = 0;

  /* attribute string organization; */
  NS_IMETHOD GetOrganization(char * *aOrganization) = 0;
  NS_IMETHOD SetOrganization(const char * aOrganization) = 0;

  /* attribute string body; */
  NS_IMETHOD GetBody(char * *aBody) = 0;
  NS_IMETHOD SetBody(const char * aBody) = 0;

  /* readonly attribute boolean isControl; */
  NS_IMETHOD GetIsControl(PRBool *aIsControl) = 0;

  /* attribute nsIFileSpec postMessageFile; */
  NS_IMETHOD GetPostMessageFile(nsIFileSpec * *aPostMessageFile) = 0;
  NS_IMETHOD SetPostMessageFile(nsIFileSpec * aPostMessageFile) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSINNTPNEWSGROUPPOST \
  NS_IMETHOD GetRelayVersion(char * *aRelayVersion); \
  NS_IMETHOD SetRelayVersion(const char * aRelayVersion); \
  NS_IMETHOD GetPostingVersion(char * *aPostingVersion); \
  NS_IMETHOD SetPostingVersion(const char * aPostingVersion); \
  NS_IMETHOD GetFrom(char * *aFrom); \
  NS_IMETHOD SetFrom(const char * aFrom); \
  NS_IMETHOD GetDate(char * *aDate); \
  NS_IMETHOD SetDate(const char * aDate); \
  NS_IMETHOD AddNewsgroup(const char *newsgroupName); \
  NS_IMETHOD GetNewsgroups(char * *aNewsgroups); \
  NS_IMETHOD GetSubject(char * *aSubject); \
  NS_IMETHOD SetSubject(const char * aSubject); \
  NS_IMETHOD GetPath(char * *aPath); \
  NS_IMETHOD SetPath(const char * aPath); \
  NS_IMETHOD GetReplyTo(char * *aReplyTo); \
  NS_IMETHOD SetReplyTo(const char * aReplyTo); \
  NS_IMETHOD GetSender(char * *aSender); \
  NS_IMETHOD SetSender(const char * aSender); \
  NS_IMETHOD GetFollowupTo(char * *aFollowupTo); \
  NS_IMETHOD SetFollowupTo(const char * aFollowupTo); \
  NS_IMETHOD GetDateRecieved(char * *aDateRecieved); \
  NS_IMETHOD SetDateRecieved(const char * aDateRecieved); \
  NS_IMETHOD GetExpires(char * *aExpires); \
  NS_IMETHOD SetExpires(const char * aExpires); \
  NS_IMETHOD GetReferences(char * *aReferences); \
  NS_IMETHOD GetControl(char * *aControl); \
  NS_IMETHOD SetControl(const char * aControl); \
  NS_IMETHOD GetDistribution(char * *aDistribution); \
  NS_IMETHOD SetDistribution(const char * aDistribution); \
  NS_IMETHOD GetOrganization(char * *aOrganization); \
  NS_IMETHOD SetOrganization(const char * aOrganization); \
  NS_IMETHOD GetBody(char * *aBody); \
  NS_IMETHOD SetBody(const char * aBody); \
  NS_IMETHOD GetIsControl(PRBool *aIsControl); \
  NS_IMETHOD GetPostMessageFile(nsIFileSpec * *aPostMessageFile); \
  NS_IMETHOD SetPostMessageFile(nsIFileSpec * aPostMessageFile); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSINNTPNEWSGROUPPOST(_to) \
  NS_IMETHOD GetRelayVersion(char * *aRelayVersion) { return _to GetRelayVersion(aRelayVersion); } \
  NS_IMETHOD SetRelayVersion(const char * aRelayVersion) { return _to SetRelayVersion(aRelayVersion); } \
  NS_IMETHOD GetPostingVersion(char * *aPostingVersion) { return _to GetPostingVersion(aPostingVersion); } \
  NS_IMETHOD SetPostingVersion(const char * aPostingVersion) { return _to SetPostingVersion(aPostingVersion); } \
  NS_IMETHOD GetFrom(char * *aFrom) { return _to GetFrom(aFrom); } \
  NS_IMETHOD SetFrom(const char * aFrom) { return _to SetFrom(aFrom); } \
  NS_IMETHOD GetDate(char * *aDate) { return _to GetDate(aDate); } \
  NS_IMETHOD SetDate(const char * aDate) { return _to SetDate(aDate); } \
  NS_IMETHOD AddNewsgroup(const char *newsgroupName) { return _to AddNewsgroup(newsgroupName); } \
  NS_IMETHOD GetNewsgroups(char * *aNewsgroups) { return _to GetNewsgroups(aNewsgroups); } \
  NS_IMETHOD GetSubject(char * *aSubject) { return _to GetSubject(aSubject); } \
  NS_IMETHOD SetSubject(const char * aSubject) { return _to SetSubject(aSubject); } \
  NS_IMETHOD GetPath(char * *aPath) { return _to GetPath(aPath); } \
  NS_IMETHOD SetPath(const char * aPath) { return _to SetPath(aPath); } \
  NS_IMETHOD GetReplyTo(char * *aReplyTo) { return _to GetReplyTo(aReplyTo); } \
  NS_IMETHOD SetReplyTo(const char * aReplyTo) { return _to SetReplyTo(aReplyTo); } \
  NS_IMETHOD GetSender(char * *aSender) { return _to GetSender(aSender); } \
  NS_IMETHOD SetSender(const char * aSender) { return _to SetSender(aSender); } \
  NS_IMETHOD GetFollowupTo(char * *aFollowupTo) { return _to GetFollowupTo(aFollowupTo); } \
  NS_IMETHOD SetFollowupTo(const char * aFollowupTo) { return _to SetFollowupTo(aFollowupTo); } \
  NS_IMETHOD GetDateRecieved(char * *aDateRecieved) { return _to GetDateRecieved(aDateRecieved); } \
  NS_IMETHOD SetDateRecieved(const char * aDateRecieved) { return _to SetDateRecieved(aDateRecieved); } \
  NS_IMETHOD GetExpires(char * *aExpires) { return _to GetExpires(aExpires); } \
  NS_IMETHOD SetExpires(const char * aExpires) { return _to SetExpires(aExpires); } \
  NS_IMETHOD GetReferences(char * *aReferences) { return _to GetReferences(aReferences); } \
  NS_IMETHOD GetControl(char * *aControl) { return _to GetControl(aControl); } \
  NS_IMETHOD SetControl(const char * aControl) { return _to SetControl(aControl); } \
  NS_IMETHOD GetDistribution(char * *aDistribution) { return _to GetDistribution(aDistribution); } \
  NS_IMETHOD SetDistribution(const char * aDistribution) { return _to SetDistribution(aDistribution); } \
  NS_IMETHOD GetOrganization(char * *aOrganization) { return _to GetOrganization(aOrganization); } \
  NS_IMETHOD SetOrganization(const char * aOrganization) { return _to SetOrganization(aOrganization); } \
  NS_IMETHOD GetBody(char * *aBody) { return _to GetBody(aBody); } \
  NS_IMETHOD SetBody(const char * aBody) { return _to SetBody(aBody); } \
  NS_IMETHOD GetIsControl(PRBool *aIsControl) { return _to GetIsControl(aIsControl); } \
  NS_IMETHOD GetPostMessageFile(nsIFileSpec * *aPostMessageFile) { return _to GetPostMessageFile(aPostMessageFile); } \
  NS_IMETHOD SetPostMessageFile(nsIFileSpec * aPostMessageFile) { return _to SetPostMessageFile(aPostMessageFile); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSINNTPNEWSGROUPPOST(_to) \
  NS_IMETHOD GetRelayVersion(char * *aRelayVersion) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetRelayVersion(aRelayVersion); } \
  NS_IMETHOD SetRelayVersion(const char * aRelayVersion) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetRelayVersion(aRelayVersion); } \
  NS_IMETHOD GetPostingVersion(char * *aPostingVersion) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetPostingVersion(aPostingVersion); } \
  NS_IMETHOD SetPostingVersion(const char * aPostingVersion) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetPostingVersion(aPostingVersion); } \
  NS_IMETHOD GetFrom(char * *aFrom) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFrom(aFrom); } \
  NS_IMETHOD SetFrom(const char * aFrom) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFrom(aFrom); } \
  NS_IMETHOD GetDate(char * *aDate) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDate(aDate); } \
  NS_IMETHOD SetDate(const char * aDate) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDate(aDate); } \
  NS_IMETHOD AddNewsgroup(const char *newsgroupName) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddNewsgroup(newsgroupName); } \
  NS_IMETHOD GetNewsgroups(char * *aNewsgroups) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNewsgroups(aNewsgroups); } \
  NS_IMETHOD GetSubject(char * *aSubject) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSubject(aSubject); } \
  NS_IMETHOD SetSubject(const char * aSubject) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSubject(aSubject); } \
  NS_IMETHOD GetPath(char * *aPath) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetPath(aPath); } \
  NS_IMETHOD SetPath(const char * aPath) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetPath(aPath); } \
  NS_IMETHOD GetReplyTo(char * *aReplyTo) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetReplyTo(aReplyTo); } \
  NS_IMETHOD SetReplyTo(const char * aReplyTo) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetReplyTo(aReplyTo); } \
  NS_IMETHOD GetSender(char * *aSender) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetSender(aSender); } \
  NS_IMETHOD SetSender(const char * aSender) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetSender(aSender); } \
  NS_IMETHOD GetFollowupTo(char * *aFollowupTo) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFollowupTo(aFollowupTo); } \
  NS_IMETHOD SetFollowupTo(const char * aFollowupTo) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetFollowupTo(aFollowupTo); } \
  NS_IMETHOD GetDateRecieved(char * *aDateRecieved) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDateRecieved(aDateRecieved); } \
  NS_IMETHOD SetDateRecieved(const char * aDateRecieved) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDateRecieved(aDateRecieved); } \
  NS_IMETHOD GetExpires(char * *aExpires) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetExpires(aExpires); } \
  NS_IMETHOD SetExpires(const char * aExpires) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetExpires(aExpires); } \
  NS_IMETHOD GetReferences(char * *aReferences) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetReferences(aReferences); } \
  NS_IMETHOD GetControl(char * *aControl) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetControl(aControl); } \
  NS_IMETHOD SetControl(const char * aControl) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetControl(aControl); } \
  NS_IMETHOD GetDistribution(char * *aDistribution) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetDistribution(aDistribution); } \
  NS_IMETHOD SetDistribution(const char * aDistribution) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetDistribution(aDistribution); } \
  NS_IMETHOD GetOrganization(char * *aOrganization) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetOrganization(aOrganization); } \
  NS_IMETHOD SetOrganization(const char * aOrganization) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetOrganization(aOrganization); } \
  NS_IMETHOD GetBody(char * *aBody) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetBody(aBody); } \
  NS_IMETHOD SetBody(const char * aBody) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetBody(aBody); } \
  NS_IMETHOD GetIsControl(PRBool *aIsControl) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetIsControl(aIsControl); } \
  NS_IMETHOD GetPostMessageFile(nsIFileSpec * *aPostMessageFile) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetPostMessageFile(aPostMessageFile); } \
  NS_IMETHOD SetPostMessageFile(nsIFileSpec * aPostMessageFile) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetPostMessageFile(aPostMessageFile); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsNNTPNewsgroupPost : public nsINNTPNewsgroupPost
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSINNTPNEWSGROUPPOST

  nsNNTPNewsgroupPost();

private:
  ~nsNNTPNewsgroupPost();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsNNTPNewsgroupPost, nsINNTPNewsgroupPost)

nsNNTPNewsgroupPost::nsNNTPNewsgroupPost()
{
  /* member initializers and constructor code */
}

nsNNTPNewsgroupPost::~nsNNTPNewsgroupPost()
{
  /* destructor code */
}

/* attribute string relayVersion; */
NS_IMETHODIMP nsNNTPNewsgroupPost::GetRelayVersion(char * *aRelayVersion)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsNNTPNewsgroupPost::SetRelayVersion(const char * aRelayVersion)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string postingVersion; */
NS_IMETHODIMP nsNNTPNewsgroupPost::GetPostingVersion(char * *aPostingVersion)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsNNTPNewsgroupPost::SetPostingVersion(const char * aPostingVersion)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string from; */
NS_IMETHODIMP nsNNTPNewsgroupPost::GetFrom(char * *aFrom)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsNNTPNewsgroupPost::SetFrom(const char * aFrom)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string date; */
NS_IMETHODIMP nsNNTPNewsgroupPost::GetDate(char * *aDate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsNNTPNewsgroupPost::SetDate(const char * aDate)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void AddNewsgroup (in string newsgroupName); */
NS_IMETHODIMP nsNNTPNewsgroupPost::AddNewsgroup(const char *newsgroupName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute string newsgroups; */
NS_IMETHODIMP nsNNTPNewsgroupPost::GetNewsgroups(char * *aNewsgroups)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string subject; */
NS_IMETHODIMP nsNNTPNewsgroupPost::GetSubject(char * *aSubject)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsNNTPNewsgroupPost::SetSubject(const char * aSubject)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string path; */
NS_IMETHODIMP nsNNTPNewsgroupPost::GetPath(char * *aPath)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsNNTPNewsgroupPost::SetPath(const char * aPath)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string replyTo; */
NS_IMETHODIMP nsNNTPNewsgroupPost::GetReplyTo(char * *aReplyTo)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsNNTPNewsgroupPost::SetReplyTo(const char * aReplyTo)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string sender; */
NS_IMETHODIMP nsNNTPNewsgroupPost::GetSender(char * *aSender)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsNNTPNewsgroupPost::SetSender(const char * aSender)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string followupTo; */
NS_IMETHODIMP nsNNTPNewsgroupPost::GetFollowupTo(char * *aFollowupTo)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsNNTPNewsgroupPost::SetFollowupTo(const char * aFollowupTo)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string dateRecieved; */
NS_IMETHODIMP nsNNTPNewsgroupPost::GetDateRecieved(char * *aDateRecieved)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsNNTPNewsgroupPost::SetDateRecieved(const char * aDateRecieved)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string expires; */
NS_IMETHODIMP nsNNTPNewsgroupPost::GetExpires(char * *aExpires)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsNNTPNewsgroupPost::SetExpires(const char * aExpires)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute string references; */
NS_IMETHODIMP nsNNTPNewsgroupPost::GetReferences(char * *aReferences)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string control; */
NS_IMETHODIMP nsNNTPNewsgroupPost::GetControl(char * *aControl)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsNNTPNewsgroupPost::SetControl(const char * aControl)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string distribution; */
NS_IMETHODIMP nsNNTPNewsgroupPost::GetDistribution(char * *aDistribution)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsNNTPNewsgroupPost::SetDistribution(const char * aDistribution)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string organization; */
NS_IMETHODIMP nsNNTPNewsgroupPost::GetOrganization(char * *aOrganization)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsNNTPNewsgroupPost::SetOrganization(const char * aOrganization)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute string body; */
NS_IMETHODIMP nsNNTPNewsgroupPost::GetBody(char * *aBody)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsNNTPNewsgroupPost::SetBody(const char * aBody)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute boolean isControl; */
NS_IMETHODIMP nsNNTPNewsgroupPost::GetIsControl(PRBool *aIsControl)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIFileSpec postMessageFile; */
NS_IMETHODIMP nsNNTPNewsgroupPost::GetPostMessageFile(nsIFileSpec * *aPostMessageFile)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsNNTPNewsgroupPost::SetPostMessageFile(nsIFileSpec * aPostMessageFile)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsINNTPNewsgroupPost_h__ */
