/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#ifndef _nsMsgDeliveryListener_H_
#define _nsMsgDeliveryListener_H_

#include "nsIUrlListener.h"
#include "nsFileSpec.h"
#include "nsMsgSend.h"
#include "nsMsgSendLater.h"

// For various delivery types
enum nsMsgDeliveryType
{
  nsMailDelivery,
  nsNewsDelivery,
  nsLocalFCCDelivery,
  nsImapFCCDelivery,
  nsFileSaveDelivery,
  nsExternalDelivery
};

// 
// This is the generic callback that will be called when the URL processing operation
// is complete. The tagData is what was passed in by the caller at creation time.
//
typedef nsresult (*nsMsgDeliveryCompletionCallback) (nsIURI *aUrl, nsresult aExitCode, nsMsgDeliveryType deliveryType, nsISupports *tagData);

class nsMsgSendLater;

class nsMsgDeliveryListener: public nsIUrlListener
{
public:
	nsMsgDeliveryListener(nsMsgDeliveryCompletionCallback callback,
                        nsMsgDeliveryType               delivType,  
                        nsISupports                     *tagData);
	virtual     ~nsMsgDeliveryListener();

	NS_DECL_ISUPPORTS

	// nsIUrlListener support
	NS_IMETHOD          OnStartRunningUrl(nsIURI * aUrl);
	NS_IMETHOD          OnStopRunningUrl(nsIURI * aUrl, nsresult aExitCode);
  NS_IMETHOD          SetMsgComposeAndSendObject(nsIMsgSend *obj);
  NS_IMETHOD          SetMsgSendLaterObject(nsMsgSendLater *obj);

private:
  // Private Information
  nsCOMPtr<nsISupports>           mTagData;
  nsFileSpec                      *mTempFileSpec;
  nsMsgDeliveryType               mDeliveryType;
  nsCOMPtr<nsIMsgSend>            mMsgSendObj;
  nsMsgSendLater                  *mMsgSendLaterObj;
  nsMsgDeliveryCompletionCallback mCompletionCallback;
};


#endif /* _nsMsgDeliveryListener_H_ */
